@@ -1,8 +1,8 @@
 from .argument import Argument
-from .colorer import Colorer, cformat, cprint
 from .command import Command, command
-from .formatter import Formatter, ManualFormatter
+from .formatter import Formatter, ManpageFormatter
 from .metadata import version
 from .mixin import Mixin, mixin
 from .option import Option
 from .parser import Parser, ParseResult, ParseError
+from .styler import Styler, sformat, sprint
