@@ -25,7 +25,7 @@ class Command(metaclass=Metaclass):
         if stack is None:
             stack = []
         if execute is None:
-            execute = self.__execute__
+            execute = self.meta_execute
         if execute.__doc__:
             self.__doc__ = execute.__doc__
         self.__name = name
@@ -48,7 +48,7 @@ class Command(metaclass=Metaclass):
         self.__invoke(argv)
         self.__stack.remove(self)
 
-    def __execute__(self):
+    def meta_execute(self):
         print(self.meta_format('help'))
 
     def meta_format(self, name, *args, delegate=None, **kwargs):
