@@ -5,8 +5,9 @@ class command(Function):
 
     # Public
 
+    # TODO: make it constant?
     marker = '_clyde_command_command'
-    protocol = 'function'
+    protocol = Function.FUNCTION
 
     def __call__(self, function):
         setattr(function, self.marker, True)
