@@ -1,7 +1,7 @@
 import re
 import inspect
 from jinja2 import Environment, PackageLoader
-from box.functools import cachedproperty
+from sugarbowl import cachedproperty
 
 
 class Formatter:
