@@ -1,3 +1,4 @@
+import inspect
 from sugarbowl import Function
 
 
@@ -5,8 +6,8 @@ class mixin(Function):
 
     # Public
 
+    # TODO: make it constant?
     decorator = '_clyde_mixin_mixin'
-    protocol = 'decorator'
 
     def __init__(self, require=None):
         self.__require = require
@@ -15,6 +16,14 @@ class mixin(Function):
         setattr(function, self.decorator, self)
         return function
 
+    def protocol(self, *args, **kwargs):
+        try:
+            if inspect.isfunction(args[0]):
+                return Function.FUNCTION
+        except IndexError:
+            pass
+        return Function.DECORATOR
+
     @property
     def require(self):
         return self.__require
